#ifndef NT2_INCLUDE_FUNCTIONS_POW_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_POW_HPP_INCLUDED

#include <nt2/exponential/include/functions/pow.hpp>

#endif
